@@ -9,8 +9,13 @@ MISSION_KEPLER = "Kepler"
 MISSION_K2 = "K2"
 MISSION_TESS = "TESS"
 SPOC_AUTHOR = "SPOC"
+KEPLER_AUTHOR = 'Kepler'
+K2_AUTHOR = 'K2'
 ELEANOR_AUTHOR = "ELEANOR"
 TESS_SPOC_AUTHOR = "TESS-SPOC"
+EVEREST_AUTHOR = "EVEREST"
 MISSION_ID_KEPLER = "KIC"
 MISSION_ID_KEPLER_2 = "EPIC"
-MISSION_ID_TESS = "TIC"
\ No newline at end of file
+MISSION_ID_TESS = "TIC"
+KBJD = 2454833.0
+TBJD = 2457000.0
\ No newline at end of file
