@@ -1,4 +1,4 @@
-__all__ = ['EleanorWarning', 'SearchError']
+__all__ = ['EleanorWarning', 'SearchError', 'EdgeProblem']
 
 class EleanorWarning(Warning):
     """A class to hold Eleanor-specific warnings."""
@@ -7,3 +7,8 @@ class EleanorWarning(Warning):
 class SearchError(Exception):
     """Exception raised when no target was found."""
     pass
+
+class EdgeProblem(Exception):
+    """ Exception raised when target is on the edge
+        of the detector. """
+    pass
